@@ -10,50 +10,42 @@
 #' @examples
 #'
 #' x <- c("y", "y", "XSF", "y", "0", "X", "0", "0", "y", "n", "0", "1", "1")
-#' recodev(original.vector = x,
-#'          old.values = c("y", "1", "n", "0"),
-#'          new.values = c(1, 1, 0, 0)
+#' recodev(
+#'   original.vector = x,
+#'   old.values = c("y", "1", "n", "0"),
+#'   new.values = c(1, 1, 0, 0)
 #' )
 #'
 #'
 #' x <- c("y", "y", "XSF", "y", "0", "X", "0", "0", "y", "n", "0", "1", "1")
-#' recodev(original.vector = x,
-#'          old.values = c("y", "1", "n", "0"),
-#'          new.values = c(1, 1, 0, 0),
-#'          others = NA
+#' recodev(
+#'   original.vector = x,
+#'   old.values = c("y", "1", "n", "0"),
+#'   new.values = c(1, 1, 0, 0),
+#'   others = NA
 #' )
 #'
-#'
-
-
-
 recodev <- function(original.vector,
-                     old.values,
-                     new.values,
-                     others = NULL) {
-
-  if(is.null(others)) {
-
+                    old.values,
+                    new.values,
+                    others = NULL) {
+  if (is.null(others)) {
     new.vector <- original.vector
-
   }
 
-  if(is.null(others) == F) {
-
-    new.vector <- rep(others,
-                      length(original.vector))
-
+  if (is.null(others) == F) {
+    new.vector <- rep(
+      others,
+      length(original.vector)
+    )
   }
 
   for (i in 1:length(old.values)) {
-
     change.log <- original.vector == old.values[i] &
       is.na(original.vector) == F
 
     new.vector[change.log] <- new.values[i]
-
   }
 
   return(new.vector)
-
 }
